/* Sliver - a BPEL execution engine for lightweight and mobile devices.
 * Copyright (C) 2006, Washington University in Saint Louis
 * By Gregory Hackmann.
 *
 * Washington University states that Sliver is free software;
 * you can redistribute it and/or modify it under the terms of
 * the current version of the GNU Lesser General Public License
 * as published by the Free Software Foundation.
 *
 * Sliver is distributed in the hope that it will be useful, but
 * THERE ARE NO WARRANTIES, WHETHER ORAL OR WRITTEN, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 * MERCHANTABILITY OR FITNESS FOR A PARTICULAR USE.
 *
 * YOU UNDERSTAND THAT SLIVER IS PROVIDED "AS IS" FOR WHICH NO
 * WARRANTIES AS TO CAPABILITIES OR ACCURACY ARE MADE. THERE ARE NO
 * WARRANTIES AND NO REPRESENTATION THAT SLIVER IS FREE OF
 * INFRINGEMENT OF THIRD PARTY PATENT, COPYRIGHT, OR OTHER
 * PROPRIETARY RIGHTS.  THERE ARE NO WARRANTIES THAT SOFTWARE IS
 * FREE FROM "BUGS", "VIRUSES", "TROJAN HORSES", "TRAP DOORS", "WORMS",
 * OR OTHER HARMFUL CODE.
 *
 * YOU ASSUME THE ENTIRE RISK AS TO THE PERFORMANCE OF SOFTWARE AND/OR
 * ASSOCIATED MATERIALS, AND TO THE PERFORMANCE AND VALIDITY OF
 * INFORMATION GENERATED USING SOFTWARE. By using Sliver you agree to
 * indemnify, defend, and hold harmless WU, its employees, officers and
 * agents from any and all claims, costs, or liabilities, including
 * attorneys fees and court costs at both the trial and appellate levels
 * for any loss, damage, or injury caused by your actions or actions of
 * your officers, servants, agents or third parties acting on behalf or
 * under authorization from you, as a result of using Sliver.
 *
 * See the GNU Lesser General Public License for more details, which can
 * be found here: http://www.gnu.org/copyleft/lesser.html
 */

/**
 * Provides the MIDP-specific parts of the Sliver SOAP server.
 * 
 * <p>Using the Sliver SOAP server under MIDP is fairly similar to the procedure
 * described in {@link edu.wustl.mobilab.sliver.soap}.  However, there are a few
 * key differences created by MIDP's limitations.
 * 
 * <ul>
 * <li>Creating classes for services is a little different.  Each class
 * must implement the {@link edu.wustl.mobilab.sliver.soap.midp.SOAPServiceProvider}
 * interface.  Sliver cannot automatically delegate requests to the appropriate
 * method within each class; instead, each class has an {@link edu.wustl.mobilab.sliver.soap.midp.SOAPServiceProvider#invoke(String,Object[]) invoke()}
 * method which is responsible for delegation.  For example:</li>
 * 
 * <blockquote><pre>// Service for namespace "http://some/Namespace"
 *public class MyService implements SOAPServiceProvider
 *{
 *    public static MyCustomType someService(...)
 *    {
 *        ...
 *        return new MyCustomType(...);
 *    }
 *    
 *    public Object invoke(String methodName, Object [] params) throws
 *        Exception
 *    {
 *        if(methodName.equals("someService"))
 *            return someService((Type1)params[0], (Type2)params[1], ...);
 *        ...
 *        else // No matching method
 *            throw new Exception("No service named " + methodName + " found");
 *    }
 *}</pre></blockquote>
 *
 * <li>The constructor for {@link edu.wustl.mobilab.sliver.soap.midp.MethodCallHandler}
 * takes in an <i>instance</i> of the class, instead of a reference to its
 * class type.</li>
 * 
 * <li>MIDP uses a different set of {@link edu.wustl.mobilab.sliver.soap.Transport}s.
 * Currently, {@link edu.wustl.mobilab.sliver.soap.midp.SocketChannel} is
 * implemented.  Note that not all MIDP devices support all connection types,
 * and it may not be possible to determine which connections a device supports
 * until runtime.</li>
 * </ul>
 * 
 * @see edu.wustl.mobilab.sliver.soap
 * @see edu.wustl.mobilab.sliver.soap.midp.SOAPServiceProvider
 * @see edu.wustl.mobilab.sliver.soap.midp.MethodCallHandler
 * @see edu.wustl.mobilab.sliver.soap.midp.SocketTransport
 */

package edu.wustl.mobilab.sliver.soap.midp;